==> catalystcoop_pudl-2024.8.0.tar.gz: catalystcoop_pudl-2024.8.0/.github/ISSUE_TEMPLATE/existing_data_updates.md <==
---
name: Integrate New Year of Data
about: Check-list for integrating a new year of data
title: ""
labels: new-data
assignees: ""
---

### New year of data integration check-list:

Based on the [Existing Data Updates Docs](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html)

- [ ] [Obtain fresh data](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#obtain-fresh-data)
- [ ] [Map the structure of the new data](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#map-the-structure-of-the-new-data)
- [ ] [Test data extraction](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#test-data-extraction)
- [ ] [Update table and column transformations](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-table-column-transformations)
- [ ] [Update the PUDL db schema](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-pudl-db-schema)
- [ ] [Connect datasets](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#connect-datasets)
- [ ] [Run the ETL](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#run-the-etl)
- [ ] [Update the output routines and run full tests](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-output-routines-and-run-full-tests)
- [ ] [Run and update data validations](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#run-and-update-data-validations)
- [ ] [Update the documentation](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-documentation)

==> catalystcoop_pudl-2024.11.0.tar.gz: catalystcoop_pudl-2024.11.0/.github/ISSUE_TEMPLATE/existing_data_updates.md <==
---
name: Integrate New Year of Data
about: Check-list for integrating a new year of data
title: ""
labels: new-data
assignees: ""
---

### New year of data integration check-list:

Based on the [Existing Data Updates Docs](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html)

- [ ] [Obtain fresh data](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#obtain-fresh-data)
- [ ] [Map the structure of the new data](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#map-the-structure-of-the-new-data)
- [ ] [Test data extraction](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#test-data-extraction)
- [ ] [Update table and column transformations](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-table-column-transformations)
- [ ] [Update the PUDL db schema](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-pudl-db-schema)
- [ ] [Connect datasets](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#connect-datasets)
- [ ] [Update the output routines](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-output-routines-and-run-full-tests)
- [ ] [Run the ETL](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#run-the-etl)
- [ ] [Run and update data validations](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#run-and-update-data-validations)
- [ ] [Update the documentation](https://catalystcoop-pudl.readthedocs.io/en/nightly/dev/existing_data_updates.html#update-the-documentation)
